@@ -13,6 +13,9 @@ describe 'octavia::api' do
       :allow_tls_terminated_listeners => false,
       :default_provider_driver        => 'ovn',
       :provider_drivers               => { 'amphora' => 'Octavia Amphora Driver', 'ovn' => 'Octavia OVN driver' },
+      :pagination_max_limit           => '1000',
+      :healthcheck_enabled            => true,
+      :healthcheck_refresh_interval   => 5,
     }
   end
 
@@ -53,6 +56,9 @@ describe 'octavia::api' do
         is_expected.to contain_octavia_config('api_settings/allow_tls_terminated_listeners').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_octavia_config('api_settings/default_provider_driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_octavia_config('api_settings/enabled_provider_drivers').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_octavia_config('api_settings/pagination_max_limit').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_octavia_config('api_settings/healthcheck_enabled').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_octavia_config('api_settings/healthcheck_refresh_interval').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_oslo__middleware('octavia_config').with(
           :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
         )
@@ -71,6 +77,9 @@ describe 'octavia::api' do
       is_expected.to contain_octavia_config('api_settings/allow_tls_terminated_listeners').with_value( params[:allow_tls_terminated_listeners] )
       is_expected.to contain_octavia_config('api_settings/default_provider_driver').with_value( params[:default_provider_driver] )
       is_expected.to contain_octavia_config('api_settings/enabled_provider_drivers').with_value( params[:provider_drivers] )
+      is_expected.to contain_octavia_config('api_settings/pagination_max_limit').with_value( params[:pagination_max_limit] )
+      is_expected.to contain_octavia_config('api_settings/healthcheck_enabled').with_value( params[:healthcheck_enabled] )
+      is_expected.to contain_octavia_config('api_settings/healthcheck_refresh_interval').with_value( params[:healthcheck_refresh_interval] )
     end
 
     [{:enabled => true}, {:enabled => false}].each do |param_hash|
@@ -126,6 +135,16 @@ describe 'octavia::api' do
       end
     end
 
+    context 'with healthcheck enabled' do
+      before do
+        params.merge!({
+          :healthcheck_enabled => true })
+      end
+
+      it 'configures healthcheck_enabled' do
+        is_expected.to contain_octavia_config('api_settings/healthcheck_enabled').with_value(true)
+      end
+    end
   end
 
   shared_examples 'octavia-api wsgi' do
