@@ -8,7 +8,7 @@ describe 'octavia::service_auth' do
         is_expected.to contain_octavia_config('service_auth/auth_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_octavia_config('service_auth/username').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_octavia_config('service_auth/project_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_octavia_config('service_auth/password').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_octavia_config('service_auth/password').with_value('<SERVICE DEFAULT>').with_secret(true)
         is_expected.to contain_octavia_config('service_auth/user_domain_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_octavia_config('service_auth/project_domain_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_octavia_config('service_auth/auth_type').with_value('<SERVICE DEFAULT>')
@@ -33,7 +33,7 @@ describe 'octavia::service_auth' do
         is_expected.to contain_octavia_config('service_auth/auth_url').with_value('http://199.199.199.199:64371')
         is_expected.to contain_octavia_config('service_auth/username').with_value('some_user')
         is_expected.to contain_octavia_config('service_auth/project_name').with_value('some_project_name')
-        is_expected.to contain_octavia_config('service_auth/password').with_value('secure123')
+        is_expected.to contain_octavia_config('service_auth/password').with_value('secure123').with_secret(true)
         is_expected.to contain_octavia_config('service_auth/user_domain_name').with_value('my_domain_name')
         is_expected.to contain_octavia_config('service_auth/project_domain_name').with_value('our_domain_name')
         is_expected.to contain_octavia_config('service_auth/auth_type').with_value('password')
